import 'package:firebase_performance/firebase_performance.dart';
import 'package:flutter/material.dart';
import 'package:url_launcher/url_launcher.dart';

/// contact us screen for the project
class ContactUs extends StatelessWidget {
  final String facebook;
  final String email;
  final String twitter;
  final String website;
  final String appName;

  /// default constructor
  /// [facebook] the facebook page
  /// [twitter] the twitter handle
  /// [website] the website for the contact form
  /// [email] the email address of the developer
  const ContactUs({
    Key? key,
    required this.facebook,
    required this.email,
    required this.twitter,
    required this.website,
    this.appName = "Contact US",
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text("Contact US"),
      ),
      body: Column(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          Text(
            appName,
            style: Theme.of(context).textTheme.headline4,
          ),
          Card(
            child: ListTile(
              title: const Text("Facebook"),
              subtitle: const Text("Inbox us on our Facebook Page"),
              onTap: () async {
                // performance tracking
                final perf = FirebasePerformance.instance
                    .newHttpMetric(facebook, HttpMethod.Get);

                perf.start();

                //launch the facebook page
                bool isURLGood = await canLaunch(facebook);
                if (isURLGood) {
                  launch(facebook);
                }

                perf.stop();
              },
            ),
          ),
          Card(
            child: ListTile(
              title: const Text("Email"),
              subtitle: const Text("Email us"),
              onTap: () async {
                // performance tracking
                final perf = FirebasePerformance.instance
                    .newHttpMetric(email, HttpMethod.Get);

                perf.start();

                //launch the facebook page
                bool isURLGood = await canLaunch(email);
                if (isURLGood) {
                  launch(email);
                }

                perf.stop();
                //launch the Email page
              },
            ),
          ),
          Card(
            child: ListTile(
              title: const Text("Twitter"),
              subtitle: const Text("DM us on twitter"),
              onTap: () async {
                // performance tracking
                final perf = FirebasePerformance.instance
                    .newHttpMetric(twitter, HttpMethod.Get);

                perf.start();

                //launch the facebook page
                bool isURLGood = await canLaunch(twitter);
                if (isURLGood) {
                  launch(twitter);
                }

                perf.stop();
                //launch the Twitter page
              },
            ),
          ),
          Card(
            child: ListTile(
              title: const Text("Website"),
              subtitle: const Text("Send us your questions from the website"),
              onTap: () async {
                // performance tracking
                final perf = FirebasePerformance.instance
                    .newHttpMetric(website, HttpMethod.Get);

                perf.start();

                //launch the website page
                bool isURLGood = await canLaunch(website);
                if (isURLGood) {
                  launch(website);
                }

                perf.stop();
              },
            ),
          ),
        ],
      ),
    );
  }
}
