import 'package:firebase_analytics/firebase_analytics.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:firebase_performance/firebase_performance.dart';
import 'package:flutter/material.dart';

class ForgotPasswordScreen extends StatefulWidget {
  const ForgotPasswordScreen({Key? key}) : super(key: key);

  @override
  _ForgotPasswordScreenState createState() => _ForgotPasswordScreenState();
}

class _ForgotPasswordScreenState extends State<ForgotPasswordScreen> {
  String? _email;
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text("Reset password link"),
      ),
      body: Center(
        child: Padding(
          padding: const EdgeInsets.all(8.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: [
              TextField(
                keyboardType: TextInputType.emailAddress,
                decoration: const InputDecoration(
                  labelText: "Email",
                  hintText: "your-name@email.com",
                  icon: Icon(Icons.email),
                ),
                onChanged: (text) {
                  setState(() {
                    _email = text;
                  });
                },
              ),
              ElevatedButton(
                child: const Text("Request reset link"),
                onPressed: _email == null
                    ? null
                    : () {
                        //record performance
                        final perf = FirebasePerformance.instance
                            .newTrace("password_reset_link");

                        //start the performance
                        perf.start();
                        FirebaseAuth.instance
                            .sendPasswordResetEmail(email: _email!)
                            .then((value) {
                          //show message
                          showDialog(
                            context: context,
                            barrierDismissible: false,
                            builder: (context) => AlertDialog(
                              title: const Text("Reset email sent"),
                              content: const Text(
                                "Please check your Emails",
                              ),
                              actions: [
                                ElevatedButton.icon(
                                  onPressed: () {
                                    Navigator.of(context).pop();
                                  },
                                  icon: const Icon(Icons.done_all),
                                  label: const Text("Done"),
                                ),
                              ],
                            ),
                          );

                          // log events
                          FirebaseAnalytics().logEvent(
                              name: "forgot_password",
                              parameters: {
                                "date": DateTime.now().millisecondsSinceEpoch,
                                "email": _email
                              });
                        }).catchError((error, stack) {
                          final err = error as FirebaseAuthException;

                          showDialog(
                            context: context,
                            builder: (context) => AlertDialog(
                              backgroundColor: Theme.of(context).errorColor,
                              title: Text("${err.code} Error"),
                              content: Text(
                                "${err.message} \n\n please try again",
                              ),
                            ),
                          );
                        });

                        //stop the performance
                        perf.stop();
                      },
              ),
            ],
          ),
        ),
      ),
    );
  }
}
