import 'package:firebase_analytics/firebase_analytics.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:white_auth/auth/state.dart';

class LoginForm extends StatefulWidget {
  const LoginForm({Key? key}) : super(key: key);

  @override
  _LoginFormState createState() => _LoginFormState();
}

class _LoginFormState extends State<LoginForm> {
  final formKey = GlobalKey();
  String? _email, _password;

  @override
  Widget build(BuildContext context) {
    final myAuth = context.watch<AuthState>();
    return Form(
      key: formKey,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          TextField(
            decoration: const InputDecoration(
              labelText: "Email",
              icon: Icon(Icons.email_outlined),
              hintText: "example@email.com",
            ),
            onChanged: (text) {
              setState(() {
                _email = text;
              });
            },
          ),
          TextField(
            decoration: const InputDecoration(
              labelText: "Password",
              icon: Icon(Icons.enhanced_encryption),
              hintText: "********",
            ),
            onChanged: (text) {
              setState(() {
                _password = text;
              });
            },
            obscureText: true,
          ),
          Container(
            padding: const EdgeInsets.all(16),
            alignment: AlignmentDirectional.centerEnd,
            child: TextButton(
              onPressed: () {
                Navigator.pushNamed(context, "/forgot");
              },
              child: const Text(
                "I forgot my password",
                style: TextStyle(
                  fontStyle: FontStyle.italic,
                ),
              ),
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: ElevatedButton(
              child: const Text("Login"),
              onPressed: () {
                FirebaseAuth.instance
                    .signInWithEmailAndPassword(
                        email: _email!, password: _password!)
                    .then((value) {
                  if (value.additionalUserInfo!.isNewUser) {
                    //add to the database
                    value.user?.sendEmailVerification();
                  }
                  FirebaseAnalytics()
                      .logLogin(loginMethod: "email_and_password");

                  Navigator.of(context).pushNamed("/home");
                }).catchError((err, stack) {
                  final error = err as FirebaseAuthException;

                  showDialog(
                    context: context,
                    builder: (context) => AlertDialog(
                      title: Text(error.code),
                      content: Text(
                        "${error.message} \n\n please try again",
                      ),
                      backgroundColor: Theme.of(context).errorColor,
                    ),
                  );
                });
              },
            ),
          ),
          const Divider(
            indent: 24,
            endIndent: 24,
            thickness: 2,
          ),
          const Text(
            "or",
            textAlign: TextAlign.center,
            style: TextStyle(fontStyle: FontStyle.italic),
          ),
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.stretch,
              children: [
                ElevatedButton.icon(
                  label: const Text(
                    " Continue with FaceBook",
                  ),
                  style: ElevatedButton.styleFrom(
                    primary: Colors.lightBlue,
                  ),
                  onPressed: () {
                    myAuth.signInWithFacebook(context: context);
                  },
                  icon: const Icon(Icons.facebook),
                ),
                ElevatedButton.icon(
                  label: const Text(" Continue with Google"),
                  onPressed: () {
                    ///TODO add google auth
                    myAuth.signInWithGoogle(context: context);
                  },
                  icon: const Icon(Icons.g_mobiledata),
                  style: ElevatedButton.styleFrom(
                    primary: Colors.red[300],
                  ),
                )
              ],
            ),
          ),
        ],
      ),
      autovalidateMode: AutovalidateMode.always,
    );
  }
}
