import 'package:firebase_analytics/firebase_analytics.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:firebase_performance/firebase_performance.dart';
import 'package:flutter/material.dart';

class RegistrationForm extends StatefulWidget {
  const RegistrationForm({Key? key}) : super(key: key);

  @override
  _RegistrationFormState createState() => _RegistrationFormState();
}

class _RegistrationFormState extends State<RegistrationForm> {
  final regFormKey = GlobalKey(debugLabel: "Registration Form");
  String? _email, _password;
  bool _nTC = false;
  @override
  Widget build(BuildContext context) {
    return Form(
      key: regFormKey,
      child: ListView(
        children: [
          TextField(
            decoration: const InputDecoration(
              labelText: "Email",
              icon: Icon(Icons.email),
              hintText: "example@email.com",
            ),
            onChanged: (text) {
              setState(() {
                _email = text;
              });
            },
          ),
          TextField(
            decoration: const InputDecoration(
              labelText: "Password",
              icon: Icon(Icons.enhanced_encryption),
              hintText: "********",
            ),
            onChanged: (text) {
              setState(() {
                _password = text;
              });
            },
            obscureText: true,
          ),
          CheckboxListTile(
            value: _nTC,
            title: const Text("I agree to terms and conditions"),
            secondary: IconButton(
              icon: const Icon(Icons.local_activity),
              onPressed: () {
                Navigator.of(context).pushNamed("/legal");
              },
            ),
            onChanged: (value) {
              setState(() {
                _nTC = value!;
              });
            },
          ),
          const Padding(
            padding: EdgeInsets.symmetric(vertical: 30),
          ),
          ElevatedButton.icon(
            icon: const Icon(Icons.account_box),
            onPressed: _nTC
                ? () {
                    //trace register
                    final perf =
                        FirebasePerformance.instance.newTrace("registration");
                    perf.start();

                    FirebaseAuth.instance
                        .createUserWithEmailAndPassword(
                            email: _email!, password: _password!)
                        .then((value) {
                      //send email verification
                      value.user?.sendEmailVerification();
                      //show message
                      ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
                        content: Text("Success"),
                      ));

                      //log event
                      FirebaseAnalytics().logSignUp(signUpMethod: "email");

                      //goto home screen
                      Navigator.of(context).pushNamed("/home");
                    }).catchError((err) {
                      final error = err as FirebaseAuthException;

                      showDialog(
                        context: context,
                        builder: (context) => AlertDialog(
                          title: Text(error.code),
                          content: Text(
                            "${error.message} \n\n please try again",
                          ),
                          backgroundColor: Theme.of(context).errorColor,
                        ),
                      );
                    });
                  }
                : null,
            label: const Text("Register"),
          )
        ],
      ),
    );
  }
}
