import 'package:firebase_analytics/firebase_analytics.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_facebook_auth/flutter_facebook_auth.dart';
import 'package:google_sign_in/google_sign_in.dart';
import 'package:flutter/foundation.dart' show kIsWeb;

class AuthState with ChangeNotifier {
  bool isLogedin = false;
  User? user;

  AuthState() {
    //set the listener
    FirebaseAuth.instance.authStateChanges().listen((myuser) {
      if (myuser == null) {
        //no user
        user = myuser;
      } else {
        isLogedin = true;
        user = myuser;
        FirebaseAnalytics().setUserId(myuser.uid);
      }
      notifyListeners();
    });
  }

  void logout() {
    FirebaseAuth.instance.signOut();
    notifyListeners();
  }

  Future<void> loginWithUserCredential({
    required BuildContext context,
    required UserCredential userCredential,
  }) async {
    //log in to firebase

    if (userCredential.additionalUserInfo!.isNewUser) {
      //add to the database
      userCredential.user!.sendEmailVerification();
    }

    Navigator.of(context).pushNamed("/home");
    // }).catchError((err, stack) {
  }

  void showError({required dynamic err, required BuildContext context}) {
    final error = err as FirebaseAuthException;

    showDialog(
      context: context,
      builder: (context) => AlertDialog(
        title: Text(error.code),
        content: Text(
          "${error.message} \n\n please try again",
        ),
        backgroundColor: Theme.of(context).errorColor,
      ),
    );
  }

  Future<void> signInWithFacebook({required BuildContext context}) async {
    if (kIsWeb) {
      FacebookAuthProvider facebookProvider = FacebookAuthProvider();

      facebookProvider.addScope('email');
      facebookProvider.setCustomParameters({
        'display': 'popup',
      });

      // Once signed in, return the UserCredential
      FirebaseAuth.instance.signInWithPopup(facebookProvider).then((value) {
        loginWithUserCredential(context: context, userCredential: value);
      }).catchError((err) {
        showError(err: err, context: context);
//show the error
      });
    }
    // Trigger the sign-in flow
    final result = await FacebookAuth.instance.login();

    if (result.status == LoginStatus.success) {
      // you are logged
      final AccessToken accessToken = result.accessToken!;
      // Create a credential from the access token
      final facebookAuthCredential =
          FacebookAuthProvider.credential(accessToken.token);
      FirebaseAuth.instance
          .signInWithCredential(facebookAuthCredential)
          .then((value) {
        loginWithUserCredential(context: context, userCredential: value);
      }).catchError((err) {
        showError(err: err, context: context);
//show the error
      });
    } else {
      print(result.status);
      print(result.message);
    }
  }

  Future<void> signInWithGoogle({required BuildContext context}) async {
    if (kIsWeb) {
      GoogleAuthProvider googleProvider = GoogleAuthProvider();

      // Once signed in, return the UserCredential
      FirebaseAuth.instance.signInWithPopup(googleProvider).then((value) {
        loginWithUserCredential(context: context, userCredential: value);
      }).catchError((err) {
        showError(err: err, context: context);
//show the error
      });
    }
    // Trigger the authentication flow
    final googleUser = await GoogleSignIn().signIn();

    // Obtain the auth details from the request
    final GoogleSignInAuthentication googleAuth =
        await googleUser!.authentication;

    // Create a new credential
    final credential = GoogleAuthProvider.credential(
      accessToken: googleAuth.accessToken,
      idToken: googleAuth.idToken,
    );

    // Once signed in, return the UserCredential
    FirebaseAuth.instance.signInWithCredential(credential).then((value) {
      loginWithUserCredential(context: context, userCredential: value);
    }).catchError((err) {
      showError(err: err, context: context);
//show the error
    });
  }
}
